spacepy.irbempy.coord_trans — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- irbempy - Python interface to irbem/ONERA library »

# spacepy.irbempy.coord_trans

`spacepy.irbempy.` `coord_trans`(loci, returntype, returncarsph)

  thin layer to call coor_trans1 from irbem lib this will convert between systems GDZ, GEO, GSM, GSE, SM, GEI, MAG, SPH, RLL

  Parameters: | - loci (Coords instance) : containing coordinate information, can contain n points returntype (str) : describing system as GDZ, GEO, GSM, GSE, SM, GEI, MAG, SPH, RLL returncarsph (str) : cartesian or spherical units ‘car’, ‘sph’
  Returns: | - xout (ndarray) : values after transformation in (n,3) dimensions

  See also

  `sph2car`, `car2sph`

  Examples

      >>> c = Coords([[3,0,0],[2,0,0]], 'GEO', 'car')
      >>> c.ticks = Ticktock(['2002-02-02T12:00:00', '2002-02-02T12:10:00'], 'ISO')
      >>> coord_trans(c, 'GSM', 'car')
      array([[ 2.8639301 , -0.01848784,  0.89306361],
      [ 1.9124434 ,  0.07209424,  0.58082929]])

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- irbempy - Python interface to irbem/ONERA library »